model

package
v0.0.0-...-ca5b39a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 7, 2026 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the model type in the database.
	Label = "model"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldDeletedAt holds the string denoting the deleted_at field in the database.
	FieldDeletedAt = "deleted_at"
	// FieldDeveloper holds the string denoting the developer field in the database.
	FieldDeveloper = "developer"
	// FieldModelID holds the string denoting the model_id field in the database.
	FieldModelID = "model_id"
	// FieldType holds the string denoting the type field in the database.
	FieldType = "type"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldIcon holds the string denoting the icon field in the database.
	FieldIcon = "icon"
	// FieldGroup holds the string denoting the group field in the database.
	FieldGroup = "group"
	// FieldModelCard holds the string denoting the model_card field in the database.
	FieldModelCard = "model_card"
	// FieldSettings holds the string denoting the settings field in the database.
	FieldSettings = "settings"
	// FieldStatus holds the string denoting the status field in the database.
	FieldStatus = "status"
	// FieldRemark holds the string denoting the remark field in the database.
	FieldRemark = "remark"
	// EdgeAdapterBindings holds the string denoting the adapter_bindings edge name in mutations.
	EdgeAdapterBindings = "adapter_bindings"
	// Table holds the table name of the model in the database.
	Table = "models"
	// AdapterBindingsTable is the table that holds the adapter_bindings relation/edge.
	AdapterBindingsTable = "adapter_model_bindings"
	// AdapterBindingsInverseTable is the table name for the AdapterModelBinding entity.
	// It exists in this package in order to avoid circular dependency with the "adaptermodelbinding" package.
	AdapterBindingsInverseTable = "adapter_model_bindings"
	// AdapterBindingsColumn is the table column denoting the adapter_bindings relation/edge.
	AdapterBindingsColumn = "model_id"
)
const DefaultStatus = StatusDisabled

StatusDisabled is the default value of the Status enum.

const DefaultType = TypeChat

TypeChat is the default value of the Type enum.

Variables

var (
	Hooks        [2]ent.Hook
	Interceptors [1]ent.Interceptor
	Policy       ent.Policy
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// DefaultDeletedAt holds the default value on creation for the "deleted_at" field.
	DefaultDeletedAt int
)

Note that the variables below are initialized by the runtime package on the initialization of the application. Therefore, it should be imported in the main as follows:

import _ "github.com/mutallipp/llm-proxy/internal/ent/runtime"

Columns holds all SQL columns for model fields.

Functions

func And

func And(predicates ...predicate.Model) predicate.Model

And groups predicates with the AND operator between them.

func CreatedAt

func CreatedAt(v time.Time) predicate.Model

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.Model

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.Model

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.Model

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.Model

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.Model

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.Model

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.Model

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.Model

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func DeletedAt

func DeletedAt(v int) predicate.Model

DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.

func DeletedAtEQ

func DeletedAtEQ(v int) predicate.Model

DeletedAtEQ applies the EQ predicate on the "deleted_at" field.

func DeletedAtGT

func DeletedAtGT(v int) predicate.Model

DeletedAtGT applies the GT predicate on the "deleted_at" field.

func DeletedAtGTE

func DeletedAtGTE(v int) predicate.Model

DeletedAtGTE applies the GTE predicate on the "deleted_at" field.

func DeletedAtIn

func DeletedAtIn(vs ...int) predicate.Model

DeletedAtIn applies the In predicate on the "deleted_at" field.

func DeletedAtLT

func DeletedAtLT(v int) predicate.Model

DeletedAtLT applies the LT predicate on the "deleted_at" field.

func DeletedAtLTE

func DeletedAtLTE(v int) predicate.Model

DeletedAtLTE applies the LTE predicate on the "deleted_at" field.

func DeletedAtNEQ

func DeletedAtNEQ(v int) predicate.Model

DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.

func DeletedAtNotIn

func DeletedAtNotIn(vs ...int) predicate.Model

DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.

func Developer

func Developer(v string) predicate.Model

Developer applies equality check predicate on the "developer" field. It's identical to DeveloperEQ.

func DeveloperContains

func DeveloperContains(v string) predicate.Model

DeveloperContains applies the Contains predicate on the "developer" field.

func DeveloperContainsFold

func DeveloperContainsFold(v string) predicate.Model

DeveloperContainsFold applies the ContainsFold predicate on the "developer" field.

func DeveloperEQ

func DeveloperEQ(v string) predicate.Model

DeveloperEQ applies the EQ predicate on the "developer" field.

func DeveloperEqualFold

func DeveloperEqualFold(v string) predicate.Model

DeveloperEqualFold applies the EqualFold predicate on the "developer" field.

func DeveloperGT

func DeveloperGT(v string) predicate.Model

DeveloperGT applies the GT predicate on the "developer" field.

func DeveloperGTE

func DeveloperGTE(v string) predicate.Model

DeveloperGTE applies the GTE predicate on the "developer" field.

func DeveloperHasPrefix

func DeveloperHasPrefix(v string) predicate.Model

DeveloperHasPrefix applies the HasPrefix predicate on the "developer" field.

func DeveloperHasSuffix

func DeveloperHasSuffix(v string) predicate.Model

DeveloperHasSuffix applies the HasSuffix predicate on the "developer" field.

func DeveloperIn

func DeveloperIn(vs ...string) predicate.Model

DeveloperIn applies the In predicate on the "developer" field.

func DeveloperLT

func DeveloperLT(v string) predicate.Model

DeveloperLT applies the LT predicate on the "developer" field.

func DeveloperLTE

func DeveloperLTE(v string) predicate.Model

DeveloperLTE applies the LTE predicate on the "developer" field.

func DeveloperNEQ

func DeveloperNEQ(v string) predicate.Model

DeveloperNEQ applies the NEQ predicate on the "developer" field.

func DeveloperNotIn

func DeveloperNotIn(vs ...string) predicate.Model

DeveloperNotIn applies the NotIn predicate on the "developer" field.

func Group

func Group(v string) predicate.Model

Group applies equality check predicate on the "group" field. It's identical to GroupEQ.

func GroupContains

func GroupContains(v string) predicate.Model

GroupContains applies the Contains predicate on the "group" field.

func GroupContainsFold

func GroupContainsFold(v string) predicate.Model

GroupContainsFold applies the ContainsFold predicate on the "group" field.

func GroupEQ

func GroupEQ(v string) predicate.Model

GroupEQ applies the EQ predicate on the "group" field.

func GroupEqualFold

func GroupEqualFold(v string) predicate.Model

GroupEqualFold applies the EqualFold predicate on the "group" field.

func GroupGT

func GroupGT(v string) predicate.Model

GroupGT applies the GT predicate on the "group" field.

func GroupGTE

func GroupGTE(v string) predicate.Model

GroupGTE applies the GTE predicate on the "group" field.

func GroupHasPrefix

func GroupHasPrefix(v string) predicate.Model

GroupHasPrefix applies the HasPrefix predicate on the "group" field.

func GroupHasSuffix

func GroupHasSuffix(v string) predicate.Model

GroupHasSuffix applies the HasSuffix predicate on the "group" field.

func GroupIn

func GroupIn(vs ...string) predicate.Model

GroupIn applies the In predicate on the "group" field.

func GroupLT

func GroupLT(v string) predicate.Model

GroupLT applies the LT predicate on the "group" field.

func GroupLTE

func GroupLTE(v string) predicate.Model

GroupLTE applies the LTE predicate on the "group" field.

func GroupNEQ

func GroupNEQ(v string) predicate.Model

GroupNEQ applies the NEQ predicate on the "group" field.

func GroupNotIn

func GroupNotIn(vs ...string) predicate.Model

GroupNotIn applies the NotIn predicate on the "group" field.

func HasAdapterBindings

func HasAdapterBindings() predicate.Model

HasAdapterBindings applies the HasEdge predicate on the "adapter_bindings" edge.

func HasAdapterBindingsWith

func HasAdapterBindingsWith(preds ...predicate.AdapterModelBinding) predicate.Model

HasAdapterBindingsWith applies the HasEdge predicate on the "adapter_bindings" edge with a given conditions (other predicates).

func ID

func ID(id int) predicate.Model

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.Model

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.Model

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.Model

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.Model

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.Model

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.Model

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.Model

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.Model

IDNotIn applies the NotIn predicate on the ID field.

func Icon

func Icon(v string) predicate.Model

Icon applies equality check predicate on the "icon" field. It's identical to IconEQ.

func IconContains

func IconContains(v string) predicate.Model

IconContains applies the Contains predicate on the "icon" field.

func IconContainsFold

func IconContainsFold(v string) predicate.Model

IconContainsFold applies the ContainsFold predicate on the "icon" field.

func IconEQ

func IconEQ(v string) predicate.Model

IconEQ applies the EQ predicate on the "icon" field.

func IconEqualFold

func IconEqualFold(v string) predicate.Model

IconEqualFold applies the EqualFold predicate on the "icon" field.

func IconGT

func IconGT(v string) predicate.Model

IconGT applies the GT predicate on the "icon" field.

func IconGTE

func IconGTE(v string) predicate.Model

IconGTE applies the GTE predicate on the "icon" field.

func IconHasPrefix

func IconHasPrefix(v string) predicate.Model

IconHasPrefix applies the HasPrefix predicate on the "icon" field.

func IconHasSuffix

func IconHasSuffix(v string) predicate.Model

IconHasSuffix applies the HasSuffix predicate on the "icon" field.

func IconIn

func IconIn(vs ...string) predicate.Model

IconIn applies the In predicate on the "icon" field.

func IconLT

func IconLT(v string) predicate.Model

IconLT applies the LT predicate on the "icon" field.

func IconLTE

func IconLTE(v string) predicate.Model

IconLTE applies the LTE predicate on the "icon" field.

func IconNEQ

func IconNEQ(v string) predicate.Model

IconNEQ applies the NEQ predicate on the "icon" field.

func IconNotIn

func IconNotIn(vs ...string) predicate.Model

IconNotIn applies the NotIn predicate on the "icon" field.

func ModelID

func ModelID(v string) predicate.Model

ModelID applies equality check predicate on the "model_id" field. It's identical to ModelIDEQ.

func ModelIDContains

func ModelIDContains(v string) predicate.Model

ModelIDContains applies the Contains predicate on the "model_id" field.

func ModelIDContainsFold

func ModelIDContainsFold(v string) predicate.Model

ModelIDContainsFold applies the ContainsFold predicate on the "model_id" field.

func ModelIDEQ

func ModelIDEQ(v string) predicate.Model

ModelIDEQ applies the EQ predicate on the "model_id" field.

func ModelIDEqualFold

func ModelIDEqualFold(v string) predicate.Model

ModelIDEqualFold applies the EqualFold predicate on the "model_id" field.

func ModelIDGT

func ModelIDGT(v string) predicate.Model

ModelIDGT applies the GT predicate on the "model_id" field.

func ModelIDGTE

func ModelIDGTE(v string) predicate.Model

ModelIDGTE applies the GTE predicate on the "model_id" field.

func ModelIDHasPrefix

func ModelIDHasPrefix(v string) predicate.Model

ModelIDHasPrefix applies the HasPrefix predicate on the "model_id" field.

func ModelIDHasSuffix

func ModelIDHasSuffix(v string) predicate.Model

ModelIDHasSuffix applies the HasSuffix predicate on the "model_id" field.

func ModelIDIn

func ModelIDIn(vs ...string) predicate.Model

ModelIDIn applies the In predicate on the "model_id" field.

func ModelIDLT

func ModelIDLT(v string) predicate.Model

ModelIDLT applies the LT predicate on the "model_id" field.

func ModelIDLTE

func ModelIDLTE(v string) predicate.Model

ModelIDLTE applies the LTE predicate on the "model_id" field.

func ModelIDNEQ

func ModelIDNEQ(v string) predicate.Model

ModelIDNEQ applies the NEQ predicate on the "model_id" field.

func ModelIDNotIn

func ModelIDNotIn(vs ...string) predicate.Model

ModelIDNotIn applies the NotIn predicate on the "model_id" field.

func Name

func Name(v string) predicate.Model

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.Model

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.Model

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.Model

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.Model

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.Model

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.Model

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.Model

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.Model

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.Model

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.Model

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.Model

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.Model

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.Model

NameNotIn applies the NotIn predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Model) predicate.Model

Or groups predicates with the OR operator between them.

func Remark

func Remark(v string) predicate.Model

Remark applies equality check predicate on the "remark" field. It's identical to RemarkEQ.

func RemarkContains

func RemarkContains(v string) predicate.Model

RemarkContains applies the Contains predicate on the "remark" field.

func RemarkContainsFold

func RemarkContainsFold(v string) predicate.Model

RemarkContainsFold applies the ContainsFold predicate on the "remark" field.

func RemarkEQ

func RemarkEQ(v string) predicate.Model

RemarkEQ applies the EQ predicate on the "remark" field.

func RemarkEqualFold

func RemarkEqualFold(v string) predicate.Model

RemarkEqualFold applies the EqualFold predicate on the "remark" field.

func RemarkGT

func RemarkGT(v string) predicate.Model

RemarkGT applies the GT predicate on the "remark" field.

func RemarkGTE

func RemarkGTE(v string) predicate.Model

RemarkGTE applies the GTE predicate on the "remark" field.

func RemarkHasPrefix

func RemarkHasPrefix(v string) predicate.Model

RemarkHasPrefix applies the HasPrefix predicate on the "remark" field.

func RemarkHasSuffix

func RemarkHasSuffix(v string) predicate.Model

RemarkHasSuffix applies the HasSuffix predicate on the "remark" field.

func RemarkIn

func RemarkIn(vs ...string) predicate.Model

RemarkIn applies the In predicate on the "remark" field.

func RemarkIsNil

func RemarkIsNil() predicate.Model

RemarkIsNil applies the IsNil predicate on the "remark" field.

func RemarkLT

func RemarkLT(v string) predicate.Model

RemarkLT applies the LT predicate on the "remark" field.

func RemarkLTE

func RemarkLTE(v string) predicate.Model

RemarkLTE applies the LTE predicate on the "remark" field.

func RemarkNEQ

func RemarkNEQ(v string) predicate.Model

RemarkNEQ applies the NEQ predicate on the "remark" field.

func RemarkNotIn

func RemarkNotIn(vs ...string) predicate.Model

RemarkNotIn applies the NotIn predicate on the "remark" field.

func RemarkNotNil

func RemarkNotNil() predicate.Model

RemarkNotNil applies the NotNil predicate on the "remark" field.

func StatusEQ

func StatusEQ(v Status) predicate.Model

StatusEQ applies the EQ predicate on the "status" field.

func StatusIn

func StatusIn(vs ...Status) predicate.Model

StatusIn applies the In predicate on the "status" field.

func StatusNEQ

func StatusNEQ(v Status) predicate.Model

StatusNEQ applies the NEQ predicate on the "status" field.

func StatusNotIn

func StatusNotIn(vs ...Status) predicate.Model

StatusNotIn applies the NotIn predicate on the "status" field.

func StatusValidator

func StatusValidator(s Status) error

StatusValidator is a validator for the "status" field enum values. It is called by the builders before save.

func TypeEQ

func TypeEQ(v Type) predicate.Model

TypeEQ applies the EQ predicate on the "type" field.

func TypeIn

func TypeIn(vs ...Type) predicate.Model

TypeIn applies the In predicate on the "type" field.

func TypeNEQ

func TypeNEQ(v Type) predicate.Model

TypeNEQ applies the NEQ predicate on the "type" field.

func TypeNotIn

func TypeNotIn(vs ...Type) predicate.Model

TypeNotIn applies the NotIn predicate on the "type" field.

func TypeValidator

func TypeValidator(_type Type) error

TypeValidator is a validator for the "type" field enum values. It is called by the builders before save.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.Model

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.Model

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.Model

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.Model

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.Model

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.Model

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.Model

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.Model

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.Model

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Model queries.

func ByAdapterBindings

func ByAdapterBindings(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByAdapterBindings orders the results by adapter_bindings terms.

func ByAdapterBindingsCount

func ByAdapterBindingsCount(opts ...sql.OrderTermOption) OrderOption

ByAdapterBindingsCount orders the results by adapter_bindings count.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByDeletedAt

func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption

ByDeletedAt orders the results by the deleted_at field.

func ByDeveloper

func ByDeveloper(opts ...sql.OrderTermOption) OrderOption

ByDeveloper orders the results by the developer field.

func ByGroup

func ByGroup(opts ...sql.OrderTermOption) OrderOption

ByGroup orders the results by the group field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByIcon

func ByIcon(opts ...sql.OrderTermOption) OrderOption

ByIcon orders the results by the icon field.

func ByModelID

func ByModelID(opts ...sql.OrderTermOption) OrderOption

ByModelID orders the results by the model_id field.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

func ByRemark

func ByRemark(opts ...sql.OrderTermOption) OrderOption

ByRemark orders the results by the remark field.

func ByStatus

func ByStatus(opts ...sql.OrderTermOption) OrderOption

ByStatus orders the results by the status field.

func ByType

func ByType(opts ...sql.OrderTermOption) OrderOption

ByType orders the results by the type field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

type Status

type Status string

Status defines the type for the "status" enum field.

const (
	StatusEnabled  Status = "enabled"
	StatusDisabled Status = "disabled"
	StatusArchived Status = "archived"
)

Status values.

func (Status) MarshalGQL

func (e Status) MarshalGQL(w io.Writer)

MarshalGQL implements graphql.Marshaler interface.

func (Status) String

func (s Status) String() string

func (*Status) UnmarshalGQL

func (e *Status) UnmarshalGQL(val interface{}) error

UnmarshalGQL implements graphql.Unmarshaler interface.

type Type

type Type string

Type defines the type for the "type" enum field.

const (
	TypeChat            Type = "chat"
	TypeEmbedding       Type = "embedding"
	TypeRerank          Type = "rerank"
	TypeImageGeneration Type = "image_generation"
	TypeVideoGeneration Type = "video_generation"
)

Type values.

func (Type) MarshalGQL

func (e Type) MarshalGQL(w io.Writer)

MarshalGQL implements graphql.Marshaler interface.

func (Type) String

func (_type Type) String() string

func (*Type) UnmarshalGQL

func (e *Type) UnmarshalGQL(val interface{}) error

UnmarshalGQL implements graphql.Unmarshaler interface.

Jump to