Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Model) predicate.Model
- func CreatedAt(v time.Time) predicate.Model
- func CreatedAtEQ(v time.Time) predicate.Model
- func CreatedAtGT(v time.Time) predicate.Model
- func CreatedAtGTE(v time.Time) predicate.Model
- func CreatedAtIn(vs ...time.Time) predicate.Model
- func CreatedAtLT(v time.Time) predicate.Model
- func CreatedAtLTE(v time.Time) predicate.Model
- func CreatedAtNEQ(v time.Time) predicate.Model
- func CreatedAtNotIn(vs ...time.Time) predicate.Model
- func DeletedAt(v int) predicate.Model
- func DeletedAtEQ(v int) predicate.Model
- func DeletedAtGT(v int) predicate.Model
- func DeletedAtGTE(v int) predicate.Model
- func DeletedAtIn(vs ...int) predicate.Model
- func DeletedAtLT(v int) predicate.Model
- func DeletedAtLTE(v int) predicate.Model
- func DeletedAtNEQ(v int) predicate.Model
- func DeletedAtNotIn(vs ...int) predicate.Model
- func Developer(v string) predicate.Model
- func DeveloperContains(v string) predicate.Model
- func DeveloperContainsFold(v string) predicate.Model
- func DeveloperEQ(v string) predicate.Model
- func DeveloperEqualFold(v string) predicate.Model
- func DeveloperGT(v string) predicate.Model
- func DeveloperGTE(v string) predicate.Model
- func DeveloperHasPrefix(v string) predicate.Model
- func DeveloperHasSuffix(v string) predicate.Model
- func DeveloperIn(vs ...string) predicate.Model
- func DeveloperLT(v string) predicate.Model
- func DeveloperLTE(v string) predicate.Model
- func DeveloperNEQ(v string) predicate.Model
- func DeveloperNotIn(vs ...string) predicate.Model
- func Group(v string) predicate.Model
- func GroupContains(v string) predicate.Model
- func GroupContainsFold(v string) predicate.Model
- func GroupEQ(v string) predicate.Model
- func GroupEqualFold(v string) predicate.Model
- func GroupGT(v string) predicate.Model
- func GroupGTE(v string) predicate.Model
- func GroupHasPrefix(v string) predicate.Model
- func GroupHasSuffix(v string) predicate.Model
- func GroupIn(vs ...string) predicate.Model
- func GroupLT(v string) predicate.Model
- func GroupLTE(v string) predicate.Model
- func GroupNEQ(v string) predicate.Model
- func GroupNotIn(vs ...string) predicate.Model
- func HasAdapterBindings() predicate.Model
- func HasAdapterBindingsWith(preds ...predicate.AdapterModelBinding) predicate.Model
- func ID(id int) predicate.Model
- func IDEQ(id int) predicate.Model
- func IDGT(id int) predicate.Model
- func IDGTE(id int) predicate.Model
- func IDIn(ids ...int) predicate.Model
- func IDLT(id int) predicate.Model
- func IDLTE(id int) predicate.Model
- func IDNEQ(id int) predicate.Model
- func IDNotIn(ids ...int) predicate.Model
- func Icon(v string) predicate.Model
- func IconContains(v string) predicate.Model
- func IconContainsFold(v string) predicate.Model
- func IconEQ(v string) predicate.Model
- func IconEqualFold(v string) predicate.Model
- func IconGT(v string) predicate.Model
- func IconGTE(v string) predicate.Model
- func IconHasPrefix(v string) predicate.Model
- func IconHasSuffix(v string) predicate.Model
- func IconIn(vs ...string) predicate.Model
- func IconLT(v string) predicate.Model
- func IconLTE(v string) predicate.Model
- func IconNEQ(v string) predicate.Model
- func IconNotIn(vs ...string) predicate.Model
- func ModelID(v string) predicate.Model
- func ModelIDContains(v string) predicate.Model
- func ModelIDContainsFold(v string) predicate.Model
- func ModelIDEQ(v string) predicate.Model
- func ModelIDEqualFold(v string) predicate.Model
- func ModelIDGT(v string) predicate.Model
- func ModelIDGTE(v string) predicate.Model
- func ModelIDHasPrefix(v string) predicate.Model
- func ModelIDHasSuffix(v string) predicate.Model
- func ModelIDIn(vs ...string) predicate.Model
- func ModelIDLT(v string) predicate.Model
- func ModelIDLTE(v string) predicate.Model
- func ModelIDNEQ(v string) predicate.Model
- func ModelIDNotIn(vs ...string) predicate.Model
- func Name(v string) predicate.Model
- func NameContains(v string) predicate.Model
- func NameContainsFold(v string) predicate.Model
- func NameEQ(v string) predicate.Model
- func NameEqualFold(v string) predicate.Model
- func NameGT(v string) predicate.Model
- func NameGTE(v string) predicate.Model
- func NameHasPrefix(v string) predicate.Model
- func NameHasSuffix(v string) predicate.Model
- func NameIn(vs ...string) predicate.Model
- func NameLT(v string) predicate.Model
- func NameLTE(v string) predicate.Model
- func NameNEQ(v string) predicate.Model
- func NameNotIn(vs ...string) predicate.Model
- func Not(p predicate.Model) predicate.Model
- func Or(predicates ...predicate.Model) predicate.Model
- func Remark(v string) predicate.Model
- func RemarkContains(v string) predicate.Model
- func RemarkContainsFold(v string) predicate.Model
- func RemarkEQ(v string) predicate.Model
- func RemarkEqualFold(v string) predicate.Model
- func RemarkGT(v string) predicate.Model
- func RemarkGTE(v string) predicate.Model
- func RemarkHasPrefix(v string) predicate.Model
- func RemarkHasSuffix(v string) predicate.Model
- func RemarkIn(vs ...string) predicate.Model
- func RemarkIsNil() predicate.Model
- func RemarkLT(v string) predicate.Model
- func RemarkLTE(v string) predicate.Model
- func RemarkNEQ(v string) predicate.Model
- func RemarkNotIn(vs ...string) predicate.Model
- func RemarkNotNil() predicate.Model
- func StatusEQ(v Status) predicate.Model
- func StatusIn(vs ...Status) predicate.Model
- func StatusNEQ(v Status) predicate.Model
- func StatusNotIn(vs ...Status) predicate.Model
- func StatusValidator(s Status) error
- func TypeEQ(v Type) predicate.Model
- func TypeIn(vs ...Type) predicate.Model
- func TypeNEQ(v Type) predicate.Model
- func TypeNotIn(vs ...Type) predicate.Model
- func TypeValidator(_type Type) error
- func UpdatedAt(v time.Time) predicate.Model
- func UpdatedAtEQ(v time.Time) predicate.Model
- func UpdatedAtGT(v time.Time) predicate.Model
- func UpdatedAtGTE(v time.Time) predicate.Model
- func UpdatedAtIn(vs ...time.Time) predicate.Model
- func UpdatedAtLT(v time.Time) predicate.Model
- func UpdatedAtLTE(v time.Time) predicate.Model
- func UpdatedAtNEQ(v time.Time) predicate.Model
- func UpdatedAtNotIn(vs ...time.Time) predicate.Model
- func ValidColumn(column string) bool
- type OrderOption
- func ByAdapterBindings(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByAdapterBindingsCount(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
- func ByDeveloper(opts ...sql.OrderTermOption) OrderOption
- func ByGroup(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByIcon(opts ...sql.OrderTermOption) OrderOption
- func ByModelID(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func ByRemark(opts ...sql.OrderTermOption) OrderOption
- func ByStatus(opts ...sql.OrderTermOption) OrderOption
- func ByType(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- type Status
- type Type
Constants ¶
const ( // Label holds the string label denoting the model type in the database. Label = "model" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldDeletedAt holds the string denoting the deleted_at field in the database. FieldDeletedAt = "deleted_at" // FieldDeveloper holds the string denoting the developer field in the database. FieldDeveloper = "developer" // FieldModelID holds the string denoting the model_id field in the database. FieldModelID = "model_id" // FieldType holds the string denoting the type field in the database. FieldType = "type" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldIcon holds the string denoting the icon field in the database. FieldIcon = "icon" // FieldGroup holds the string denoting the group field in the database. FieldGroup = "group" // FieldModelCard holds the string denoting the model_card field in the database. FieldModelCard = "model_card" // FieldSettings holds the string denoting the settings field in the database. FieldSettings = "settings" // FieldStatus holds the string denoting the status field in the database. FieldStatus = "status" // FieldRemark holds the string denoting the remark field in the database. FieldRemark = "remark" // EdgeAdapterBindings holds the string denoting the adapter_bindings edge name in mutations. EdgeAdapterBindings = "adapter_bindings" // Table holds the table name of the model in the database. Table = "models" // AdapterBindingsTable is the table that holds the adapter_bindings relation/edge. AdapterBindingsTable = "adapter_model_bindings" // AdapterBindingsInverseTable is the table name for the AdapterModelBinding entity. // It exists in this package in order to avoid circular dependency with the "adaptermodelbinding" package. AdapterBindingsInverseTable = "adapter_model_bindings" // AdapterBindingsColumn is the table column denoting the adapter_bindings relation/edge. AdapterBindingsColumn = "model_id" )
const DefaultStatus = StatusDisabled
StatusDisabled is the default value of the Status enum.
const DefaultType = TypeChat
TypeChat is the default value of the Type enum.
Variables ¶
var ( Hooks [2]ent.Hook Interceptors [1]ent.Interceptor Policy ent.Policy // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultDeletedAt holds the default value on creation for the "deleted_at" field. DefaultDeletedAt int )
Note that the variables below are initialized by the runtime package on the initialization of the application. Therefore, it should be imported in the main as follows:
import _ "github.com/mutallipp/llm-proxy/internal/ent/runtime"
var Columns = []string{ FieldID, FieldCreatedAt, FieldUpdatedAt, FieldDeletedAt, FieldDeveloper, FieldModelID, FieldType, FieldName, FieldIcon, FieldGroup, FieldModelCard, FieldSettings, FieldStatus, FieldRemark, }
Columns holds all SQL columns for model fields.
Functions ¶
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func DeletedAt ¶
DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.
func DeletedAtEQ ¶
DeletedAtEQ applies the EQ predicate on the "deleted_at" field.
func DeletedAtGT ¶
DeletedAtGT applies the GT predicate on the "deleted_at" field.
func DeletedAtGTE ¶
DeletedAtGTE applies the GTE predicate on the "deleted_at" field.
func DeletedAtIn ¶
DeletedAtIn applies the In predicate on the "deleted_at" field.
func DeletedAtLT ¶
DeletedAtLT applies the LT predicate on the "deleted_at" field.
func DeletedAtLTE ¶
DeletedAtLTE applies the LTE predicate on the "deleted_at" field.
func DeletedAtNEQ ¶
DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.
func DeletedAtNotIn ¶
DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.
func Developer ¶
Developer applies equality check predicate on the "developer" field. It's identical to DeveloperEQ.
func DeveloperContains ¶
DeveloperContains applies the Contains predicate on the "developer" field.
func DeveloperContainsFold ¶
DeveloperContainsFold applies the ContainsFold predicate on the "developer" field.
func DeveloperEQ ¶
DeveloperEQ applies the EQ predicate on the "developer" field.
func DeveloperEqualFold ¶
DeveloperEqualFold applies the EqualFold predicate on the "developer" field.
func DeveloperGT ¶
DeveloperGT applies the GT predicate on the "developer" field.
func DeveloperGTE ¶
DeveloperGTE applies the GTE predicate on the "developer" field.
func DeveloperHasPrefix ¶
DeveloperHasPrefix applies the HasPrefix predicate on the "developer" field.
func DeveloperHasSuffix ¶
DeveloperHasSuffix applies the HasSuffix predicate on the "developer" field.
func DeveloperIn ¶
DeveloperIn applies the In predicate on the "developer" field.
func DeveloperLT ¶
DeveloperLT applies the LT predicate on the "developer" field.
func DeveloperLTE ¶
DeveloperLTE applies the LTE predicate on the "developer" field.
func DeveloperNEQ ¶
DeveloperNEQ applies the NEQ predicate on the "developer" field.
func DeveloperNotIn ¶
DeveloperNotIn applies the NotIn predicate on the "developer" field.
func Group ¶
Group applies equality check predicate on the "group" field. It's identical to GroupEQ.
func GroupContains ¶
GroupContains applies the Contains predicate on the "group" field.
func GroupContainsFold ¶
GroupContainsFold applies the ContainsFold predicate on the "group" field.
func GroupEqualFold ¶
GroupEqualFold applies the EqualFold predicate on the "group" field.
func GroupHasPrefix ¶
GroupHasPrefix applies the HasPrefix predicate on the "group" field.
func GroupHasSuffix ¶
GroupHasSuffix applies the HasSuffix predicate on the "group" field.
func GroupNotIn ¶
GroupNotIn applies the NotIn predicate on the "group" field.
func HasAdapterBindings ¶
HasAdapterBindings applies the HasEdge predicate on the "adapter_bindings" edge.
func HasAdapterBindingsWith ¶
func HasAdapterBindingsWith(preds ...predicate.AdapterModelBinding) predicate.Model
HasAdapterBindingsWith applies the HasEdge predicate on the "adapter_bindings" edge with a given conditions (other predicates).
func IconContains ¶
IconContains applies the Contains predicate on the "icon" field.
func IconContainsFold ¶
IconContainsFold applies the ContainsFold predicate on the "icon" field.
func IconEqualFold ¶
IconEqualFold applies the EqualFold predicate on the "icon" field.
func IconHasPrefix ¶
IconHasPrefix applies the HasPrefix predicate on the "icon" field.
func IconHasSuffix ¶
IconHasSuffix applies the HasSuffix predicate on the "icon" field.
func ModelID ¶
ModelID applies equality check predicate on the "model_id" field. It's identical to ModelIDEQ.
func ModelIDContains ¶
ModelIDContains applies the Contains predicate on the "model_id" field.
func ModelIDContainsFold ¶
ModelIDContainsFold applies the ContainsFold predicate on the "model_id" field.
func ModelIDEqualFold ¶
ModelIDEqualFold applies the EqualFold predicate on the "model_id" field.
func ModelIDGTE ¶
ModelIDGTE applies the GTE predicate on the "model_id" field.
func ModelIDHasPrefix ¶
ModelIDHasPrefix applies the HasPrefix predicate on the "model_id" field.
func ModelIDHasSuffix ¶
ModelIDHasSuffix applies the HasSuffix predicate on the "model_id" field.
func ModelIDLTE ¶
ModelIDLTE applies the LTE predicate on the "model_id" field.
func ModelIDNEQ ¶
ModelIDNEQ applies the NEQ predicate on the "model_id" field.
func ModelIDNotIn ¶
ModelIDNotIn applies the NotIn predicate on the "model_id" field.
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func Remark ¶
Remark applies equality check predicate on the "remark" field. It's identical to RemarkEQ.
func RemarkContains ¶
RemarkContains applies the Contains predicate on the "remark" field.
func RemarkContainsFold ¶
RemarkContainsFold applies the ContainsFold predicate on the "remark" field.
func RemarkEqualFold ¶
RemarkEqualFold applies the EqualFold predicate on the "remark" field.
func RemarkHasPrefix ¶
RemarkHasPrefix applies the HasPrefix predicate on the "remark" field.
func RemarkHasSuffix ¶
RemarkHasSuffix applies the HasSuffix predicate on the "remark" field.
func RemarkIsNil ¶
RemarkIsNil applies the IsNil predicate on the "remark" field.
func RemarkNotIn ¶
RemarkNotIn applies the NotIn predicate on the "remark" field.
func RemarkNotNil ¶
RemarkNotNil applies the NotNil predicate on the "remark" field.
func StatusNotIn ¶
StatusNotIn applies the NotIn predicate on the "status" field.
func StatusValidator ¶
StatusValidator is a validator for the "status" field enum values. It is called by the builders before save.
func TypeValidator ¶
TypeValidator is a validator for the "type" field enum values. It is called by the builders before save.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Model queries.
func ByAdapterBindings ¶
func ByAdapterBindings(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByAdapterBindings orders the results by adapter_bindings terms.
func ByAdapterBindingsCount ¶
func ByAdapterBindingsCount(opts ...sql.OrderTermOption) OrderOption
ByAdapterBindingsCount orders the results by adapter_bindings count.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByDeletedAt ¶
func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
ByDeletedAt orders the results by the deleted_at field.
func ByDeveloper ¶
func ByDeveloper(opts ...sql.OrderTermOption) OrderOption
ByDeveloper orders the results by the developer field.
func ByGroup ¶
func ByGroup(opts ...sql.OrderTermOption) OrderOption
ByGroup orders the results by the group field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByIcon ¶
func ByIcon(opts ...sql.OrderTermOption) OrderOption
ByIcon orders the results by the icon field.
func ByModelID ¶
func ByModelID(opts ...sql.OrderTermOption) OrderOption
ByModelID orders the results by the model_id field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func ByRemark ¶
func ByRemark(opts ...sql.OrderTermOption) OrderOption
ByRemark orders the results by the remark field.
func ByStatus ¶
func ByStatus(opts ...sql.OrderTermOption) OrderOption
ByStatus orders the results by the status field.
func ByType ¶
func ByType(opts ...sql.OrderTermOption) OrderOption
ByType orders the results by the type field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
type Status ¶
type Status string
Status defines the type for the "status" enum field.
const ( StatusEnabled Status = "enabled" StatusDisabled Status = "disabled" StatusArchived Status = "archived" )
Status values.
func (Status) MarshalGQL ¶
MarshalGQL implements graphql.Marshaler interface.
func (*Status) UnmarshalGQL ¶
UnmarshalGQL implements graphql.Unmarshaler interface.
type Type ¶
type Type string
Type defines the type for the "type" enum field.
const ( TypeChat Type = "chat" TypeEmbedding Type = "embedding" TypeRerank Type = "rerank" TypeImageGeneration Type = "image_generation" TypeVideoGeneration Type = "video_generation" )
Type values.
func (Type) MarshalGQL ¶
MarshalGQL implements graphql.Marshaler interface.
func (*Type) UnmarshalGQL ¶
UnmarshalGQL implements graphql.Unmarshaler interface.